@@ -1,4 +1,4 @@
-# Copyright (C)  2012-2017   Mark Seligman
+# Copyright (C)  2012-2018   Mark Seligman
 ##
 ## This file is part of ArboristBridgeR.
 ##
@@ -17,19 +17,5 @@
 
 PreTrain.default <- function(x) {
   .Deprecated("PreFormat")
-    
-  # Argument checking:
-  if (any(is.na(x)))
-    stop("NA not supported in design matrix")
-
-  predBlock <- PredBlock(x)
-  rowRank <- .Call("RcppRowRank", predBlock)
-
-  preTrain <- list(
-    predBlock = predBlock,
-    rowRank = rowRank
-  )
-  class(preTrain) <- "PreTrain"
-
-  preTrain
+  PreFormat(x)
 }
