@@ -15,9 +15,19 @@
 
 #include "ompthread.h"
 
-#include "omp.h"
 #include <algorithm>
 
+// Cribbed from data.table.
+#ifdef _OPENMP
+  #include <omp.h>
+#else
+  #define omp_get_num_threads() 1
+  #define omp_get_max_threads() 1
+  #define omp_get_thread_limit() 1
+  #define omp_get_thread_num() 0
+  #define omp_set_nested(a) // Dummied out.
+#endif
+
 unsigned int OmpThread::nThread = OmpThread::nThreadDefault;
 
 void OmpThread::init(unsigned int nThread_) {
